@@ -5,12 +5,11 @@ References:
 - https://github.com/ytdl-org/youtube-dl/blob/master/README.md#embedding-youtube-dl
 - https://github.com/ytdl-org/youtube-dl/blob/3e4cedf9e8cd3157df2457df7274d0c842421945/youtube_dl/YoutubeDL.py#L137-L312
 """
-import os
 from typing import List
 
 import youtube_dl
 
-from pyscrapers.configs import ConfigYoutubeDl, ConfigDownload
+from pyscrapers.configs import ConfigYoutubeDl, ConfigYoutubeUrl
 
 
 class MyLogger(object):
@@ -26,21 +25,21 @@ class MyLogger(object):
 
 
 def youtube_dl_handler() -> None:
-    youtube_dl_download_url(ConfigYoutubeDl.url, ConfigDownload.folder)
+    youtube_dl_download_url(ConfigYoutubeUrl.url)
 
 
-def youtube_dl_download_url(url: str, folder: str) -> None:
-    youtube_dl_download_urls([url], folder)
+def youtube_dl_download_url(url: str) -> None:
+    youtube_dl_download_urls([url])
 
 
-def youtube_dl_download_urls(urls: List[str], folder: str) -> None:
+def youtube_dl_download_urls(urls: List[str]) -> None:
     ydl_opts = {
         'format': 'bestaudio/best',
         # 'logger': MyLogger(),
         'nooverwrites': True,
         'ignoreerrors': True,
-        'outtmpl': os.path.join(folder, '%(title)s-%(id)s.%(ext)s'),
-        'download_archive': os.path.expanduser('~/.config/youtube-dl-archive'),
     }
+    if ConfigYoutubeDl.use_archive:
+        ydl_opts['download_archive'] = ConfigYoutubeDl.archive_file
     with youtube_dl.YoutubeDL(ydl_opts) as ydl:
         ydl.download(urls)
